package net.minecraft.src;

import java.util.Random;

public class EntitySheep extends EntityAnimal {
	public static final float[][] fleeceColorTable = new float[][]{{1.0F, 1.0F, 1.0F}, {0.95F, 0.7F, 0.2F}, {0.9F, 0.5F, 0.85F}, {0.6F, 0.7F, 0.95F}, {0.9F, 0.9F, 0.2F}, {0.5F, 0.8F, 0.1F}, {0.95F, 0.7F, 0.8F}, {0.3F, 0.3F, 0.3F}, {0.6F, 0.6F, 0.6F}, {0.3F, 0.6F, 0.7F}, {0.7F, 0.4F, 0.9F}, {0.2F, 0.4F, 0.8F}, {0.5F, 0.4F, 0.3F}, {0.4F, 0.5F, 0.2F}, {0.8F, 0.3F, 0.3F}, {0.1F, 0.1F, 0.1F}};
	private int field_44007_b;

	public EntitySheep(World world1) {
		super(world1);
		this.texture = "/mob/sheep.png";
		this.setSize(0.9F, 1.3F);
	}

	public int getMaxHealth() {
		return 8;
	}

	protected void entityInit() {
		super.entityInit();
		this.dataWatcher.addObject(16, new Byte((byte)0));
	}

	protected void dropFewItems(boolean z1, int i2) {
		if(!this.getSheared()) {
			this.entityDropItem(new ItemStack(Block.cloth.blockID, 1, this.getFleeceColor()), 0.0F);
		}

	}

	protected int getDropItemId() {
		return Block.cloth.blockID;
	}

	public void onLivingUpdate() {
		super.onLivingUpdate();
		if(this.field_44007_b > 0) {
			--this.field_44007_b;
		}

	}

	protected void jump() {
		if(this.field_44007_b <= 0) {
			super.jump();
		}

	}

	protected void updateEntityActionState() {
		super.updateEntityActionState();
		int i1;
		int i2;
		int i3;
		if(!this.hasPath() && this.field_44007_b <= 0 && (this.isChild() && this.rand.nextInt(50) == 0 || this.rand.nextInt(1000) == 0)) {
			i1 = MathHelper.floor_double(this.posX);
			i2 = MathHelper.floor_double(this.posY);
			i3 = MathHelper.floor_double(this.posZ);
			if(this.worldObj.getBlockId(i1, i2, i3) == Block.tallGrass.blockID && this.worldObj.getBlockMetadata(i1, i2, i3) == 1 || this.worldObj.getBlockId(i1, i2 - 1, i3) == Block.grass.blockID) {
				this.field_44007_b = 40;
				this.worldObj.sendTrackedEntityStatusUpdatePacket(this, (byte)10);
			}
		} else if(this.field_44007_b == 4) {
			i1 = MathHelper.floor_double(this.posX);
			i2 = MathHelper.floor_double(this.posY);
			i3 = MathHelper.floor_double(this.posZ);
			boolean z4 = false;
			if(this.worldObj.getBlockId(i1, i2, i3) == Block.tallGrass.blockID) {
				this.worldObj.playAuxSFX(2001, i1, i2, i3, Block.tallGrass.blockID + 256);
				this.worldObj.setBlockWithNotify(i1, i2, i3, 0);
				z4 = true;
			} else if(this.worldObj.getBlockId(i1, i2 - 1, i3) == Block.grass.blockID) {
				this.worldObj.playAuxSFX(2001, i1, i2 - 1, i3, Block.grass.blockID);
				this.worldObj.setBlockWithNotify(i1, i2 - 1, i3, Block.dirt.blockID);
				z4 = true;
			}

			if(z4) {
				this.setSheared(false);
				if(this.isChild()) {
					int i5 = this.getDelay() + 1200;
					if(i5 > 0) {
						i5 = 0;
					}

					this.setDelay(i5);
				}
			}
		}

	}

	protected boolean isMovementCeased() {
		return this.field_44007_b > 0;
	}

	public boolean interact(EntityPlayer entityPlayer1) {
		ItemStack itemStack2 = entityPlayer1.inventory.getCurrentItem();
		if(itemStack2 != null && itemStack2.itemID == Item.shears.shiftedIndex && !this.getSheared() && !this.isChild()) {
			if(!this.worldObj.singleplayerWorld) {
				this.setSheared(true);
				int i3 = 1 + this.rand.nextInt(3);

				for(int i4 = 0; i4 < i3; ++i4) {
					EntityItem entityItem5 = this.entityDropItem(new ItemStack(Block.cloth.blockID, 1, this.getFleeceColor()), 1.0F);
					entityItem5.motionY += (double)(this.rand.nextFloat() * 0.05F);
					entityItem5.motionX += (double)((this.rand.nextFloat() - this.rand.nextFloat()) * 0.1F);
					entityItem5.motionZ += (double)((this.rand.nextFloat() - this.rand.nextFloat()) * 0.1F);
				}
			}

			itemStack2.damageItem(1, entityPlayer1);
		}

		return super.interact(entityPlayer1);
	}

	public void writeEntityToNBT(NBTTagCompound nBTTagCompound1) {
		super.writeEntityToNBT(nBTTagCompound1);
		nBTTagCompound1.setBoolean("Sheared", this.getSheared());
		nBTTagCompound1.setByte("Color", (byte)this.getFleeceColor());
	}

	public void readEntityFromNBT(NBTTagCompound nBTTagCompound1) {
		super.readEntityFromNBT(nBTTagCompound1);
		this.setSheared(nBTTagCompound1.getBoolean("Sheared"));
		this.setFleeceColor(nBTTagCompound1.getByte("Color"));
	}

	protected String getLivingSound() {
		return "mob.sheep";
	}

	protected String getHurtSound() {
		return "mob.sheep";
	}

	protected String getDeathSound() {
		return "mob.sheep";
	}

	public int getFleeceColor() {
		return this.dataWatcher.getWatchableObjectByte(16) & 15;
	}

	public void setFleeceColor(int i1) {
		byte b2 = this.dataWatcher.getWatchableObjectByte(16);
		this.dataWatcher.updateObject(16, (byte)(b2 & 240 | i1 & 15));
	}

	public boolean getSheared() {
		return (this.dataWatcher.getWatchableObjectByte(16) & 16) != 0;
	}

	public void setSheared(boolean z1) {
		byte b2 = this.dataWatcher.getWatchableObjectByte(16);
		if(z1) {
			this.dataWatcher.updateObject(16, (byte)(b2 | 16));
		} else {
			this.dataWatcher.updateObject(16, (byte)(b2 & -17));
		}

	}

	public static int getRandomFleeceColor(Random random0) {
		int i1 = random0.nextInt(100);
		return i1;
	}

	protected EntityAnimal spawnBabyAnimal(EntityAnimal entityAnimal1) {
		EntitySheep entitySheep2 = (EntitySheep)entityAnimal1;
		EntitySheep entitySheep3 = new EntitySheep(this.worldObj);
		if(this.rand.nextBoolean()) {
			entitySheep3.setFleeceColor(this.getFleeceColor());
		} else {
			entitySheep3.setFleeceColor(entitySheep2.getFleeceColor());
		}

		return entitySheep3;
	}
}
